==> ogre-1.12_1.12.4+dfsg1.orig.tar.xz: ogre-1.12/PlugIns/BSPSceneManager/src/OgreBspSceneLoader.cpp <==
/*
-----------------------------------------------------------------------------
This source file is part of OGRE
    (Object-oriented Graphics Rendering Engine)
For the latest info, see http://www.ogre3d.org/

Copyright (c) 2000-2014 Torus Knot Software Ltd

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
THE SOFTWARE.
-----------------------------------------------------------------------------
*/
#include "OgreBspSceneLoader.h"
#include "OgreBspLevel.h"
#include "OgreQuake3ShaderManager.h"
#include "OgreSceneLoaderManager.h"
#include "OgreBspSceneManager.h"
#include "OgreSceneNode.h"

namespace Ogre {

    //-----------------------------------------------------------------------
    BspSceneLoader::BspSceneLoader()
    {
        // Also create related shader manager (singleton managed)
        mShaderMgr = OGRE_NEW Quake3ShaderManager();

        std::vector<String> exts = {".bsp"};
        SceneLoaderManager::getSingleton().registerSceneLoader("Q3BSP", exts, this);
    }
    //-----------------------------------------------------------------------
    BspSceneLoader::~BspSceneLoader()
    {
        OGRE_DELETE mShaderMgr;
        SceneLoaderManager::getSingleton().unregisterSceneLoader("Q3BSP");
    }
    //-----------------------------------------------------------------------
    void BspSceneLoader::load(DataStreamPtr& stream,
        const String& group, SceneNode *rootNode)
    {
        BspSceneManager* mgr = dynamic_cast<BspSceneManager*>(rootNode->getCreator());

        OgreAssert(mgr, "only loading into a BspSceneManager supported");

        mgr->setLevel(BspLevelPtr()); // clear

        BspLevelPtr bspLevel(new BspLevel(NULL, "bsplevel", 0, group, false, NULL));
        bspLevel->load(stream);

        mgr->setLevel(bspLevel);
    }

}

==> ogre-1.12_1.12.10+dfsg2.orig.tar.xz: ogre-1.12-1.12.10+dfsg2/PlugIns/BSPSceneManager/src/OgreBspSceneLoader.cpp <==
/*
-----------------------------------------------------------------------------
This source file is part of OGRE
    (Object-oriented Graphics Rendering Engine)
For the latest info, see http://www.ogre3d.org/

Copyright (c) 2000-2014 Torus Knot Software Ltd

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
THE SOFTWARE.
-----------------------------------------------------------------------------
*/
#include "OgreBspSceneLoader.h"
#include "OgreCodec.h"

namespace Ogre {

    //-----------------------------------------------------------------------
    BspSceneLoader::BspSceneLoader() {}
    BspSceneLoader::~BspSceneLoader() {}
    //-----------------------------------------------------------------------
    void BspSceneLoader::load(DataStreamPtr& stream, const String& group, SceneNode* rootNode)
    {
        Codec::getCodec("bsp")->decode(stream, rootNode);
    }
}
